@@ -1,4 +1,4 @@
-__version__ = '0.9.2'
+__version__ = '0.10'
 
 
 def description(message):
@@ -49,6 +49,14 @@ def fcontext(message):
     pass
 
 
+def shared_context(message):
+    pass
+
+
+def included_context(message):
+    pass
+
+
 def before():
     pass
 
